@@ -44,57 +44,68 @@ plot(graph_object, vertex.color = "grey75")
 #  library("igraph")
 #  adjacency_matrix <- igraph::as_adjacency_matrix(graph_object)
 
-## ---- eval=!module-------------------------------------------------------
-partition <- c(rep(1, 20), rep(2, 20), rep(3, 20))
-table(partition)
+## ---- eval=!module,echo=FALSE, message=FALSE, warning=FALSE, results="hide"----
+#  partition <- c(rep(1, 20), rep(2, 20), rep(3, 20))
 
 ## ---- eval=module--------------------------------------------------------
-#  partition <- leiden(adjacency_matrix)
-#  table(partition)
+partition <- leiden(adjacency_matrix)
+
+## ------------------------------------------------------------------------
+table(partition)
 
 ## ---- warning=FALSE, message=FALSE---------------------------------------
 library("RColorBrewer")
-node.cols <- brewer.pal(max(partition),"Pastel1")[partition]
+node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
 plot(graph_object, vertex.color = node.cols)
 
 ## ---- eval=module--------------------------------------------------------
-#  #run with defaults
-#    partition <- leiden(adjacency_matrix)
-#  
-#  
-#  #run with ModularityVertexPartition"
-#    partition <- leiden(adjacency_matrix, partition_type = "ModularityVertexPartition")
-#  
-#  
-#  #run with resolution parameter
-#    partition <- leiden(adjacency_matrix, resolution_parameter = 0.95)
+#run with defaults
+  partition <- leiden(adjacency_matrix)
+
+
+#run with ModularityVertexPartition"
+  partition <- leiden(adjacency_matrix, partition_type = "ModularityVertexPartition")
+
+
+#run with resolution parameter
+  partition <- leiden(adjacency_matrix, resolution_parameter = 0.95)
 
 ## ---- warning=FALSE, message=FALSE, eval=module--------------------------
-#  partition <- leiden(adjacency_matrix, resolution_parameter = 0.5)
-#  node.cols <- brewer.pal(max(partition),"Pastel1")[partition]
-#  plot(graph_object, vertex.color = node.cols)
+partition <- leiden(adjacency_matrix, resolution_parameter = 0.5)
+node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
+plot(graph_object, vertex.color = node.cols)
 
 ## ---- warning=FALSE, message=FALSE, eval=module--------------------------
-#  partition <- leiden(adjacency_matrix, resolution_parameter = 1.8)
-#  node.cols <- brewer.pal(max(partition),"Pastel1")[partition]
-#  plot(graph_object, vertex.color = node.cols)
+partition <- leiden(adjacency_matrix, resolution_parameter = 1.8)
+node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
+plot(graph_object, vertex.color = node.cols)
 
 ## ---- warning=FALSE, message=FALSE, eval=module--------------------------
-#  #generate example weights
-#  weights <- sample(1:10, sum(adjacency_matrix!=0), replace=TRUE)
-#  partition <- leiden(adjacency_matrix, weights = weights)
-#  table(partition)
+#generate example weights
+weights <- sample(1:10, sum(adjacency_matrix!=0), replace=TRUE)
+partition <- leiden(adjacency_matrix, weights = weights)
+table(partition)
 
 ## ---- warning=FALSE, message=FALSE, eval=module--------------------------
-#  #generate example weighted matrix
-#  adjacency_matrix[adjacency_matrix == 1] <- weights
-#  partition <- leiden(adjacency_matrix)
-#  table(partition)
+#generate example weighted matrix
+adjacency_matrix[adjacency_matrix == 1] <- weights
+partition <- leiden(adjacency_matrix)
+table(partition)
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  adjacency_matrix <- as.matrix(object@snn)
 #  membership <- leiden(adjacency_matrix)
 #  object@ident <- as.factor(membership)
-#  names(test@ident) <- rownames(test@meta.data)
+#  names(object@ident) <- rownames(object@meta.data)
 #  object@meta.data$ident <- as.factor(membership)
 
+## ---- eval=FALSE---------------------------------------------------------
+#  library("Seurat")
+#  FindClusters(pbmc_small)
+#  membership <- leiden(pbmc_small@graphs$RNA_snn)
+#  table(membership)
+
+## ---- eval=FALSE---------------------------------------------------------
+#  FindClusters(pbmc_small, algorithm = "leiden")
+#  table(pbmc_small@active.ident)
+
